@@ -13,8 +13,7 @@ from trytond.modules.product import price_digits
 __all__ = ['ShipmentIn', 'Move']
 
 
-class ShipmentIn:
-    __metaclass__ = PoolMeta
+class ShipmentIn(metaclass=PoolMeta):
     __name__ = 'stock.shipment.in'
     carrier = fields.Many2One('carrier', 'Carrier', states={
             'readonly': Eval('state') != 'draft',
@@ -42,7 +41,7 @@ class ShipmentIn:
     def _get_carrier_context(self):
         return {}
 
-    @fields.depends(methods=['incoming_moves'])
+    @fields.depends(methods=['on_change_incoming_moves'])
     def on_change_carrier(self):
         self.on_change_incoming_moves()
 
@@ -139,8 +138,7 @@ class ShipmentIn:
         super(ShipmentIn, cls).receive(shipments)
 
 
-class Move:
-    __metaclass__ = PoolMeta
+class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
     unit_shipment_cost = fields.Numeric('Unit Shipment Cost',
         digits=price_digits, readonly=True)
